@@ -40,6 +40,8 @@ typedef enum {
 	NAUTILUS_FILE_ATTRIBUTE_LARGE_TOP_LEFT_TEXT = 1 << 7,
 	NAUTILUS_FILE_ATTRIBUTE_EXTENSION_INFO = 1 << 8,
 	NAUTILUS_FILE_ATTRIBUTE_THUMBNAIL = 1 << 9,
+	NAUTILUS_FILE_ATTRIBUTE_MOUNT = 1 << 10,
+	NAUTILUS_FILE_ATTRIBUTE_FILESYSTEM_INFO = 1 << 11,
 } NautilusFileAttributes;
 
 #endif /* NAUTILUS_FILE_ATTRIBUTES_H */
