@@ -191,7 +191,7 @@ save_entry (GtkEntry *entry, GnomeDesktopItem *item)
 	error = NULL;
 
 	if (!gnome_desktop_item_save (item, NULL, TRUE, &error)) {
-		g_warning (error->message);
+		g_warning ("%s", error->message);
 		g_error_free (error);
 	}
 }
