@@ -201,7 +201,7 @@ connect_to_server (NautilusConnectServerDialog *dialog)
 
 		server = gtk_editable_get_chars (GTK_EDITABLE (dialog->details->server_entry), 0, -1);
 		if (strlen (server) == 0) {
-			eel_show_error_dialog (_("Can't Connect to Server. You must enter a name for the server."), 
+			eel_show_error_dialog (_("Cannot Connect to Server. You must enter a name for the server."), 
 					       _("Please enter a name and try again."), 
 					       GTK_WINDOW (dialog));
 			g_free (server);
@@ -325,10 +325,6 @@ connect_to_server (NautilusConnectServerDialog *dialog)
 	nautilus_connect_server_dialog_present_uri (dialog->details->application,
 						    location,
 						    GTK_WIDGET (dialog));
-
-	g_object_unref (location);
-
-	gtk_widget_destroy (GTK_WIDGET (dialog));
 }
 
 static void
@@ -779,6 +775,13 @@ port_insert_text (GtkEditable *editable,
 	}
 }
 
+static void
+bookmark_checkmark_toggled (GtkToggleButton *toggle, NautilusConnectServerDialog *dialog)
+{
+	gtk_widget_set_sensitive (GTK_WIDGET(dialog->details->name_entry),
+		gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON (toggle)));
+}
+
 static void
 nautilus_connect_server_dialog_init (NautilusConnectServerDialog *dialog)
 {
@@ -907,6 +910,12 @@ nautilus_connect_server_dialog_init (NautilusConnectServerDialog *dialog)
 	dialog->details->bookmark_check = gtk_check_button_new_with_mnemonic (_("Add _bookmark"));
 	dialog->details->name_entry = gtk_entry_new ();
 
+	g_signal_connect (dialog->details->bookmark_check, "toggled", 
+			  G_CALLBACK (bookmark_checkmark_toggled), dialog);
+
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->details->bookmark_check), FALSE);
+	gtk_widget_set_sensitive (GTK_WIDGET(dialog->details->name_entry), FALSE);
+
 	gtk_entry_set_activates_default (GTK_ENTRY (dialog->details->uri_entry), TRUE);
 	gtk_entry_set_activates_default (GTK_ENTRY (dialog->details->server_entry), TRUE);
 	gtk_entry_set_activates_default (GTK_ENTRY (dialog->details->share_entry), TRUE);
