@@ -115,10 +115,6 @@ static void remove_extra_location_widgets             (NautilusWindow
 void
 nautilus_window_report_selection_changed (NautilusWindowInfo *window)
 {
-	if (window->details->temporarily_ignore_view_signals) {
-		return;
-	}
-
 	g_signal_emit_by_name (window, "selection_changed");
 }
 
@@ -189,7 +185,7 @@ handle_go_back (NautilusNavigationWindow *window, GFile *location)
         GList *link;
         NautilusBookmark *bookmark;
 
-        g_return_if_fail (NAUTILUS_IS_NAVIGATION_WINDOW (window));
+        g_assert (NAUTILUS_IS_NAVIGATION_WINDOW (window));
 
         /* Going back. Move items from the back list to the forward list. */
         g_assert (g_list_length (window->back_list) > NAUTILUS_WINDOW (window)->details->location_change_distance);
@@ -228,7 +224,7 @@ handle_go_forward (NautilusNavigationWindow *window, GFile *location)
         GList *link;
         NautilusBookmark *bookmark;
 
-        g_return_if_fail (NAUTILUS_IS_NAVIGATION_WINDOW (window));
+        g_assert (NAUTILUS_IS_NAVIGATION_WINDOW (window));
 
         /* Going forward. Move items from the forward list to the back list. */
         g_assert (g_list_length (window->forward_list) > NAUTILUS_WINDOW (window)->details->location_change_distance);
@@ -629,16 +625,6 @@ nautilus_window_open_location_with_selection (NautilusWindow *window,
 					    flags, selection);
 }					      
 
-char *
-nautilus_window_get_view_label (NautilusWindow *window)
-{
-	const NautilusViewInfo *info;
-
-	info = nautilus_view_factory_lookup (nautilus_window_get_content_view_id (window));
-
-	return g_strdup (info->label);
-}
-
 char *
 nautilus_window_get_view_error_label (NautilusWindow *window)
 {
@@ -1227,10 +1213,6 @@ void
 nautilus_window_report_load_underway (NautilusWindow *window,
 				      NautilusView *view)
 {
-	if (window->details->temporarily_ignore_view_signals) {
-		return;
-	}
-
         g_assert (NAUTILUS_IS_WINDOW (window));
 
         if (view == window->new_content_view) {
@@ -1530,10 +1512,6 @@ void
 nautilus_window_report_load_complete (NautilusWindow *window,
 				      NautilusView *view)
 {
-	if (window->details->temporarily_ignore_view_signals) {
-		return;
-	}
-
         g_assert (NAUTILUS_IS_WINDOW (window));
 
 	/* Only handle this if we're expecting it.
@@ -1598,10 +1576,6 @@ free_location_change (NautilusWindow *window)
         }
 
         if (window->new_content_view != NULL) {
-		window->details->temporarily_ignore_view_signals = TRUE;
-		nautilus_view_stop_loading (window->new_content_view);
-		window->details->temporarily_ignore_view_signals = FALSE;
-
                 disconnect_view (window, window->new_content_view);
         	g_object_unref (window->new_content_view);
                 window->new_content_view = NULL;
@@ -1640,13 +1614,9 @@ nautilus_window_report_view_failed (NautilusWindow *window,
 {
 	gboolean do_close_window;
 	GFile *fallback_load_location;
-
-	if (window->details->temporarily_ignore_view_signals) {
-		return;
-	}
-
         g_warning ("A view failed. The UI will handle this with a dialog but this should be debugged.");
 
+
 	do_close_window = FALSE;
 	fallback_load_location = NULL;
 	
@@ -1708,13 +1678,13 @@ display_view_selection_failure (NautilusWindow *window, NautilusFile *file,
 	if (error == NULL) {
 		if (nautilus_file_is_directory (file)) {
 			error_message = g_strdup_printf
-				(_("Couldn't display \"%s\"."),
+				(_("Could not display \"%s\"."),
 				 uri_for_display);
 			detail_message = g_strdup 
 				(_("Nautilus has no installed viewer capable of displaying the folder."));
 		} else {
 			error_message = g_strdup_printf
-				(_("Couldn't display \"%s\"."),
+				(_("Could not display \"%s\"."),
 				 uri_for_display);
 			detail_message = g_strdup 
 				(_("The location is not a folder."));
@@ -1723,7 +1693,7 @@ display_view_selection_failure (NautilusWindow *window, NautilusFile *file,
 		switch (error->code) {
 		case G_IO_ERROR_NOT_FOUND:
 			error_message = g_strdup_printf
-				(_("Couldn't find \"%s\"."), 
+				(_("Could not find \"%s\"."), 
 				 uri_for_display);
 			detail_message = g_strdup 
 				(_("Please check the spelling and try again."));
@@ -1731,10 +1701,10 @@ display_view_selection_failure (NautilusWindow *window, NautilusFile *file,
 		case G_IO_ERROR_NOT_SUPPORTED:
 			scheme_string = g_file_get_uri_scheme (location);
 				
-			error_message = g_strdup_printf (_("Couldn't display \"%s\"."),
+			error_message = g_strdup_printf (_("Could not display \"%s\"."),
 							 uri_for_display);
 			if (scheme_string != NULL) {
-				detail_message = g_strdup_printf (_("Nautilus cannot handle %s: locations."),
+				detail_message = g_strdup_printf (_("Nautilus cannot handle \"%s\" locations."),
 								  scheme_string);
 			} else {
 				detail_message = g_strdup (_("Nautilus cannot handle this kind of locations."));
@@ -1742,13 +1712,13 @@ display_view_selection_failure (NautilusWindow *window, NautilusFile *file,
 			g_free (scheme_string);
 			break;
 		case G_IO_ERROR_NOT_MOUNTED:
-			error_message = g_strdup_printf (_("Couldn't display \"%s\"."),
+			error_message = g_strdup_printf (_("Could not display \"%s\"."),
 							 uri_for_display);
 			detail_message = g_strdup (_("Unable to mount the location."));
 			break;
 			
 		case G_IO_ERROR_PERMISSION_DENIED:
-			error_message = g_strdup_printf (_("Couldn't display \"%s\"."),
+			error_message = g_strdup_printf (_("Could not display \"%s\"."),
 							 uri_for_display);
 			detail_message = g_strdup (_("Access was denied."));
 			break;
@@ -1759,7 +1729,7 @@ display_view_selection_failure (NautilusWindow *window, NautilusFile *file,
 			 * But this case is also hit for legitimate web addresses when
 			 * the proxy is set up wrong.
 			 */
-			error_message = g_strdup_printf (_("Couldn't display \"%s\", because the host could be found."),
+			error_message = g_strdup_printf (_("Could not display \"%s\", because the host could not be found."),
 							 uri_for_display);
 			detail_message = g_strdup (_("Check that the spelling is correct and that your proxy settings are correct."));
 			break;
@@ -1773,7 +1743,7 @@ display_view_selection_failure (NautilusWindow *window, NautilusFile *file,
 	}
 	
 	if (error_message == NULL) {
-		error_message = g_strdup_printf (_("Couldn't display \"%s\"."),
+		error_message = g_strdup_printf (_("Could not display \"%s\"."),
 						 uri_for_display);
 		detail_message = g_strdup_printf (_("Error: %s\nPlease select another viewer and try again."), error->message);
 	}
@@ -1792,9 +1762,7 @@ nautilus_window_stop_loading (NautilusWindow *window)
 	nautilus_view_stop_loading (window->content_view);
 	
 	if (window->new_content_view != NULL) {
-		window->details->temporarily_ignore_view_signals = TRUE;
 		nautilus_view_stop_loading (window->new_content_view);
-		window->details->temporarily_ignore_view_signals = FALSE;
 	}
 
         cancel_location_change (window);
