@@ -286,7 +286,7 @@ real_set_allow_up (NautilusWindow *window,
 {
 	GtkAction *action;
 	
-        g_return_if_fail (NAUTILUS_IS_WINDOW (window));
+        g_assert (NAUTILUS_IS_WINDOW (window));
 
 	action = gtk_action_group_get_action (window->details->main_action_group,
 					      NAUTILUS_ACTION_UP);
@@ -639,6 +639,11 @@ nautilus_window_finalize (GObject *object)
 
 	g_free (window->details->title);
 
+	if (window->details->find_mount_cancellable != NULL) {
+		g_cancellable_cancel (window->details->find_mount_cancellable);
+		window->details->find_mount_cancellable = NULL;
+	}
+
 	G_OBJECT_CLASS (nautilus_window_parent_class)->finalize (object);
 }
 
@@ -820,7 +825,7 @@ add_view_as_menu_item (NautilusWindow *window,
 	
 	g_snprintf (action_name, sizeof (action_name), "view_as_%d", index);
 	action = gtk_radio_action_new (action_name,
-				       _(info->view_as_label_with_mnemonic),
+				       _(info->view_menu_label_with_mnemonic),
 				       _(info->display_location_label),
 				       NULL,
 				       0);
@@ -947,7 +952,7 @@ nautilus_window_synch_view_as_menus (NautilusWindow *window)
 	GList *node;
 	GtkAction *action;
 
-	g_return_if_fail (NAUTILUS_IS_WINDOW (window));
+	g_assert (NAUTILUS_IS_WINDOW (window));
 
 	if (window->content_view == NULL) {
 		return;
@@ -1180,7 +1185,7 @@ static void
 nautilus_window_set_title (NautilusWindow *window, 
 			   const char *title)
 {
-	g_return_if_fail (NAUTILUS_IS_WINDOW (window));
+	g_assert (NAUTILUS_IS_WINDOW (window));
 
 	EEL_CALL_METHOD (NAUTILUS_WINDOW_CLASS, window,
                          set_title, (window, title));
@@ -1236,8 +1241,8 @@ nautilus_window_update_icon (NautilusWindow *window)
 			
 			if (pixbuf) {
 				gtk_window_set_icon (GTK_WINDOW (window), pixbuf);
+				g_object_unref (pixbuf);
 			} 
-			g_object_unref (pixbuf);
 		}
 		
 		g_object_unref (info);
@@ -1251,8 +1256,8 @@ real_set_content_view_widget (NautilusWindow *window,
 {
 	GtkWidget *widget;
 	
-	g_return_if_fail (NAUTILUS_IS_WINDOW (window));
-	g_return_if_fail (new_view == NULL || NAUTILUS_IS_VIEW (new_view));
+	g_assert (NAUTILUS_IS_WINDOW (window));
+	g_assert (new_view == NULL || NAUTILUS_IS_VIEW (new_view));
 	
 	if (new_view == window->content_view) {
 		return;
@@ -1541,7 +1546,7 @@ nautilus_window_get_history (NautilusWindow *window)
 static NautilusWindowType
 nautilus_window_get_window_type (NautilusWindow *window)
 {
-	g_return_val_if_fail (NAUTILUS_IS_WINDOW (window), NAUTILUS_WINDOW_SPATIAL);
+	g_assert (NAUTILUS_IS_WINDOW (window));
 
 	return NAUTILUS_WINDOW_GET_CLASS (window)->window_type;
 }
